banshee r4246 - in trunk/banshee: . src/Core/Banshee.Services/Banshee.Sources



Author: blorentz
Date: Thu Jul 24 21:27:20 2008
New Revision: 4246
URL: http://svn.gnome.org/viewvc/banshee?rev=4246&view=rev

Log:
2008-07-24  Bertrand Lorentz  <bertrand lorentz gmail com>

	* src/Core/Banshee.Services/Banshee.Sources/DatabaseSource.cs: Fix the 
	comparison between the field column and the current sort column, so that
	"CoreTracks.skippedcount" doesn't match "Track". Makes BGO #544415 less
	likely to happen, but doesn't fix it.



Modified:
   trunk/banshee/ChangeLog
   trunk/banshee/src/Core/Banshee.Services/Banshee.Sources/DatabaseSource.cs

Modified: trunk/banshee/src/Core/Banshee.Services/Banshee.Sources/DatabaseSource.cs
==============================================================================
--- trunk/banshee/src/Core/Banshee.Services/Banshee.Sources/DatabaseSource.cs	(original)
+++ trunk/banshee/src/Core/Banshee.Services/Banshee.Sources/DatabaseSource.cs	Thu Jul 24 21:27:20 2008
@@ -171,9 +171,9 @@
             ISortableColumn sort_column = (TrackModel is DatabaseTrackListModel)
                 ? (TrackModel as DatabaseTrackListModel).SortColumn : null;
             // If it's the field we're sorting by, then yes, we care
             // FIXME this Contains is very hacky, we should link the ISortableColumn to a field and/or a
             // QueryOrder object
-            if (sort_column != null && field.Column.Contains (sort_column.SortKey)) {
+            if (sort_column != null && field.Column.EndsWith (sort_column.SortKey)) {
                 return true;
             }
 
@@ -171,9 +171,9 @@
                 ? (TrackModel as DatabaseTrackListModel).SortColumn : null;
             // If it's the field we're sorting by, then yes, we care
-            // FIXME this Contains is very hacky, we should link the ISortableColumn to a field and/or a
+            // FIXME this EndsWith is very hacky, we should link the ISortableColumn to a field and/or a
             // QueryOrder object



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]